{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Solve World Problems</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/solve_world_problems_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/solve_world_problems_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/solve_world_problems_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/solve_world_problems_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/solve_world_problems_650.jpg' %}"
                     alt="Students and faculties on a boat in Puget Sound studying various fish.">
            
            
        </figure>
        <div class="myuw-article-body">
        <p>Many paths are available to you to make a difference in the world, and your contributions will be welcome, however large or small. Most problems facing humanity are extremely complex, and their solutions require thousands of contributors, from many disciplines and with diverse skill sets.</p>


<h3>Strategies to Get You Started</h3>
<p>If you're set on tackling world issues, you might start by identifying the ways you like to tackle and solve problems generally. Do you like being "up close and personal" with a problem – on the ground administering vaccines, for example – or do you prefer to address "the big picture" – maybe monitoring the path of an epidemic? The next step is to identify which disciplines (and majors) best align with your preferred approach. One way to do this is by searching UW.edu or UW Today for news about faculty or organizations working on the issues you care about. Find the people mentioned and make an appointment to talk to them. Try to get a sense of the following:</p>
<ul>
<li>How are they approaching the problem?</li>
<li>What types of questions are they asking?</li> 
<li>What tools and methods are they bringing to bear on the problem?</li> 
<li>What knowledge and skills do they anticipate will be needed to effectively address this problem in the future?</li>
</ul>
<p>Another strategy is to <a href="https://myplan.uw.edu" target="_blank">search for courses</a> with key words related to the issue you care about. Talk to a librarian to learn more about the perspectives different disciplines bring to bear on this issue. Know of a major that might be of interest? Find someone in that major and talk to them about how problems are approached in that discipline.</p>


<h3>Forge a New Path</h3>
<p>Finally, recognize that you may get to create your own career path through a combination of courses and majors; it's rare to find a major that exactly matches a career. Remember the world is constantly changing, and the job you end up doing may not yet exist!</p>
        </div>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus – Learning or Competing?</a></li>
                
                    <li><a href="/husky_experience_message?article=do-majors-jobs">Do Majors = Jobs?</a></li>
                
                    <li><a href="/husky_experience_message?article=got-experience">Got Experience?</a></li>
                
                    <li><a href="/husky_experience_message?article=what-if-grade-didnt-matter">What If the Grade Didn&#39;t Matter?</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
