# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-12-15 03:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hx_toolkit', '0002_auto_20171212_0058'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='image',
            field=models.ImageField(upload_to=b'hx_toolkit_images'),
        ),
        migrations.AlterField(
            model_name='article',
            name='quarter',
            field=models.CharField(blank=True, choices=[(b'autumn', b'Autumn'), (b'winter', b'Winter'), (b'spring', b'Spring'), (b'summer', b'Summer')], max_length=6, null=True),
        ),
    ]
