{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Got Experience?</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/got_experience_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/got_experience_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/got_experience_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/got_experience_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/got_experience_650.jpg' %}"
                     alt="A team of students works with the Burke Museum to excavate a whale at Grayland Beach State Park.">
            
            
        </figure>
        <div class="myuw-article-body">
        <p>No matter where you are in your undergraduate career, you can always branch out and get experiences that will augment your classroom learning.</p>


<h3>Internships</h3>
<p>Internships – an opportunity to learn while working – are one way. The Career and Internship Center has resources for all stages; they can help you search for and find internships and also help you make sense of the experience later. Staff at the Career and Internship Center talked to students who shared <a href="https://youtu.be/oCz3pR5j8p0">their internship advice</a>.</p>


<h3>Options Beyond Internships</h3>
<p>Experience can also be found through other learning experiences outside the classroom like <a href="http://www.washington.edu/undergradresearch/">undergraduate research</a> and <a href="http://www.washington.edu/carlson/students-3/browse-service-learning-positions/">service learning</a> or <a href="http://www.washington.edu/carlson/service-opportunities/">volunteering</a>. This is not just about working in a lab or volunteering at a food bank – there are literally hundreds of different ways to contribute. You might be surprised by what you find. </p>

<p>Doing something new and making connections with others can be scary. Remember that stepping out of your comfort zone can feel awkward and uncertain, but almost always results in rich rewards.</p>
        </div>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=solve-world-problems">Solve World Problems</a></li>
                
                    <li><a href="/husky_experience_message?article=pitch-your-story">Pitch Your Story</a></li>
                
                    <li><a href="/husky_experience_message?article=does-your-resume-represent-you">Does Your Résumé Represent You?</a></li>
                
                    <li><a href="/husky_experience_message?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
