{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Bouncing Back</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/bouncing_back_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/bouncing_back_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/bouncing_back_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/bouncing_back_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/bouncing_back_650.jpg' %}"
                     alt="Roses in bloom at the rose garden surrounding Drumheller Fountain.">
            
            
                <p class="myuw-image-credit">Photo: Katherine B. Turner</p>
            
        </figure>
        <div class="myuw-article-body">
        <p>You may have heard about a “fixed” vs. “growth” mindset. A mindset, or pattern of beliefs, can affect thoughts and behaviors positively or negatively.</p>

<h3>A Fixed Mindset</h3>
<p>In a “fixed mindset,” people believe that things like intelligence, character, and creative abilities are fixed traits. They may have been praised for their abilities when they were younger and may feel like they don’t need to put in a lot of effort because their achievements have always “just come naturally.” When people with a fixed mindset encounter a genuine challenge, they begin to doubt their abilities and avoid taking risks in the future, for fear of looking like a failure or having their deficiencies exposed. They’re also not very good at hearing critical feedback, because what they hear is that someone is disappointed in them, not that there are ways that they can improve their work, or their relationships.</p>

<h3>A Growth Mindset</h3>
<p>In contrast, people with a “growth mindset” believe that qualities like intelligence, creativity, and even the capacity for positive relationships can be developed through effort and practice. They are not defined by their failures, but see them as an opportunity to try harder next time. When they encounter a challenge, they’re motivated to find a solution and may encourage themselves with the thought, “I don’t have the answer&#8230;yet.” In addition, people with a growth mindset welcome critical feedback, because they know it will tell them where they need to place their effort in order to succeed, in their work or relationships.</p>


<h3>Cultivating Resilience</h3>
<p>You may have a fixed or growth mindset at different times in your life, or in different areas of your life. It’s worth learning more about these mindsets, as well as strategies for altering fixed beliefs. A growth mindset will help you improve your attitude toward failure, your comfort taking risks, and your chances for success. Practice it now, and it will serve you well into the future.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://www.youtube.com/watch?v=KUWn_TJTrnU">Growth Mindset vs. Fixed Mindset</a></li>
                
                    <li><a href="https://www.youtube.com/watch?v=aNHas97iE78">4 Steps to a Developing a Growth Mindset</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus – Learning or Competing?</a></li>
                
                    <li><a href="/husky_experience_message?article=no-time-be-healthy">No Time to be Healthy?</a></li>
                
                    <li><a href="/husky_experience_message?article=are-you-your-gpa">Are you your GPA?</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
