{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Tools to Help You Along the Way</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/tools_to_help_along_the_way_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/tools_to_help_along_the_way_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/tools_to_help_along_the_way_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/tools_to_help_along_the_way_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/tools_to_help_along_the_way_650.jpg' %}"
                     alt="Two students walk through the quad on the second day of Fall quarter.">
            
            
                <p class="myuw-image-credit">Photo: Katherine B. Turner</p>
            
        </figure>
        <div class="myuw-article-body">
        <p>Creating your Husky Experience is an opportunity unique to you, but you don’t have to start from scratch or go it alone. We are a team of UW staff members who spent time collecting suggestions – from students, faculty, and other staff – on how to help all students successfully create the kind of Husky Experience that will serve them well.</p>

<p>The Husky Experience Toolkit is a collection of suggestions to help you challenge yourself, think about options, and weave together all you are learning. They are being delivered via MyUW so that all students have access to these ideas and resources.<p>

<p>Watch this space for a new message each week, or visit the <a href="/husky_experience">Husky Experience page</a> any time.</p>
        </div>
        

        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
