{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Plan Your Life by Accident</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/plan_life_by_accident_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/plan_life_by_accident_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/plan_life_by_accident_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/plan_life_by_accident_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/plan_life_by_accident_650.jpg' %}"
                     alt="An Environmental Science student explores the rings of a tree on a field trip in the North Cascades.">
            
            
        </figure>
        <div class="myuw-article-body">
        <p>Sometimes you intend to have an experience, like an internship in your field of interest. Other times, there's "just what happened" – like when your internship doesn't pan out and a friend ropes you into volunteering for Alternative Spring Break, or someone nominates you to be on a panel talking about your undergrad research project. </p>


<h3>Mining for Insights</h3>
<p>How do you make the most of these "accidental" experiences? Mine them for information about what does – and does not – engage you. Did the experience bring you joy? Did it sap your energy or fire you up? To get more detailed insights, try the “AEIOU” method.</p>

<p>Here’s how Bill Burnett and Dave Evans describe the method in their book, “Designing Your Life”:</p>

<ul>
<li><strong>Activities</strong> – What were you actually doing? Was this a structured or unstructured activity? Did you have a specific role to play (team leader) or were you just a participant (at a meeting)?</li>
<li><strong>Environments</strong> – Our environment has a profound effect on our emotional state. You feel one way at a football stadium, another in a cathedral. Notice where you were when you were involved in the activity. What kind of place was it, and how did it make you feel?</li>
<li><strong>Interactions</strong> – What were you interacting with–people or machines? Was it a new kind of interaction or one you are familiar with? Was it formal or informal?</li>
<li><strong>Objects</strong> – Were you interacting with any objects or devices–iPads or smartphones, hockey sticks or sailboats? What were the objects that created or supported your feeling engaged?</li>
<li><strong>Users</strong> – Who else was there and what role did they play in making it either a positive or negative experience?</li>
</ul>


<h3>The Benefits</h3>
<p>When you’re able to identify specifically what makes an experience delightful or dull, you can wisely choose a next experience, and you’re on your way to designing a fulfilling and happy life.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://www.youtube.com/watch?v=SemHh0n19LA">Designing Your Life, TEDXStanford</a></li>
                
                    <li><a href="http://www.nytimes.com/2010/08/03/opinion/03brooks.html?ref=opinion">The Summoned Self</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=falling-love-class">Falling in Love with a Class</a></li>
                
                    <li><a href="/husky_experience_message?article=solve-world-problems">Solve World Problems</a></li>
                
                    <li><a href="/husky_experience_message?article=do-majors-jobs">Do Majors = Jobs?</a></li>
                
                    <li><a href="/husky_experience_message?article=got-experience">Got Experience?</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
