{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Tired of Feeling Alone?</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/tired_feeling_alone_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/tired_feeling_alone_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/tired_feeling_alone_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/tired_feeling_alone_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/tired_feeling_alone_650.jpg' %}"
                     alt="A crowd of students walking to classes on Red Square.">
            
            
                <p class="myuw-image-credit">Photo: Dennis Wise</p>
            
        </figure>
        <div class="myuw-article-body">
        <p>One thing we've heard from students is that it's a lot easier to make friends with people who share your interests once you're in a major. Until then, however, it can be challenging, especially if you’re taking large lecture courses where it may be difficult to get to know your classmates.</p>


<h3>The Right Fit</h3>
<p>Some people get lucky and instantly bond with roommates, or teammates, or find the community they're looking for in an RSO. If you're still feeling like you haven't met your peeps, however, don’t give up. Finding true friends takes time, patience, and a little effort. Following are some strategies that might pay off.

<h3>Conversations Over Time</h3>
<p>First, look for opportunities to have increasingly more substantive conversations with others over time. Over the course of a quarter, classes, and maybe study groups are two places you're likely to see the same people repeatedly. Try to learn more about the people around you each time you meet. Strategies include: </p>
<ul>
<li><strong>Study groups</strong> – Try taking 5 minutes at the start of your group for all members to “check in” and share in a sentence or two how they are and what’s going on for them. You’ll get to know each other better this way, and can always follow up after the study session is over.</li>
<li><strong>Classes</strong> – In small classes, it's a lot easier to see the same people repeatedly. Take advantage of time before and after class, or when assigned to a group, to introduce yourself. Over time, move from talking about things related to the class to things beyond the class. Students often say that the quarter ends just as they’re starting to know their classmates. If you’re not sure you’ll see a classmate again but would like to continue getting to know them, tell them. It can be as simple as, “It was fun working with you this quarter. Would you like to keep in touch?”</li>
</ul>

<h3>Express Your Values</h3>
<p>Second, express your values. Often the people we “click” with are people who share our values or interests, or who have similar personality traits or life experiences. The values or experiences that count, however, may not be visible from the outside. Look for ways that people elect to show what they care about – joining RSOs, volunteering, participating in certain events – and do the same. Get to know some people in these environments, and ask them to introduce you to other people they know. The more broad your interactions, the more likely you’ll eventually find the folks that make you feel at home.</p>

<h3>Serendipity</h3>
<p>Finally, be open to chance opportunities to engage with people around you. You never know when a shared experience (missed bus?) will lead you to discover that you and a stranger have something meaningful in common.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://collegeinfogeek.com/make-friends-college/">How to Make Friends in College</a></li>
                
                    <li><a href="https://www.youtube.com/watch?time_continue=129&amp;v=5n6gbpCqA5g">Friendship &amp; Vulnerability</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
                
                    <li><a href="/husky_experience_message?article=your-friends-your-success">Your Friends, Your Success</a></li>
                
                    <li><a href="/husky_experience_message?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
