{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Pitch Your Story</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/pitch_your_story_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/pitch_your_story_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/pitch_your_story_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/pitch_your_story_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/pitch_your_story_650.jpg' %}"
                     alt="Students mingle with guests during a Master of Fine Arts event.">
            
            
                <p class="myuw-image-credit">Photo: UW College of Arts &amp; Sciences</p>
            
        </figure>
        <div class="myuw-article-body">
        <h3>Prepare to Connect</h3>
        <p>Introducing yourself in social or professional settings can often lead to future opportunities. Whether you’re attending a formal job fair or mingling at an event, you want to capture a person’s attention and make an impression in a few minutes. Taking time to prepare an introduction makes it easier to establish social or professional contacts. Media experts know that what you convey in these first moments is key to guiding conversations where you want them to go, increasing the likelihood that you’ll get across information you want to share and succeed in making a memorable impression.</p>

<p>An effective way to connect and to convey your message is a personal elevator pitch. This is a clear, concise, and specific statement that describes you, your interests, and your strengths in less than 30 seconds.</p>


<h3>Ways to Pitch Your Story</h3>
<p>Here are ways to prepare your pitch:</p>
<ul>
<li>Try creating a few sentences about who you are, what you're seeking, and what you can offer. Consider including what you care about, and what you like doing.</li> 

<li>Prepare and practice your pitch so it flows naturally. Practice alone and with friends so that you feel comfortable introducing yourself to new people.</li> 

<li>Tweak your pitch often to keep it current and to adapt it to each situation you are in.</li>

<li>Be prepared for the next step in the conversation – describing your experience, skills, and the contributions you hope to make.</li>
</ul>
<p>Ideally your “elevator pitch” will leave someone wanting to know more about you and lead to a longer conversation or additional connections.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://www.gcflearnfree.org/jobsearchandnetworking/networking-basics/1/">Job Search and Networking Basics</a></li>
                
                    <li><a href="https://idealistcareers.org/a-quick-guide-to-writing-your-elevator-pitch-with-examples/">A Quick Guide to Writing Your Elevator Pitch</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=jobs-come-through-people-you-know">Jobs Come Through People You Know</a></li>
                
                    <li><a href="/husky_experience_message?article=your-friends-your-success">Your Friends, Your Success</a></li>
                
                    <li><a href="/husky_experience_message?article=does-your-resume-represent-you">Does Your Résumé Represent You?</a></li>
                
                    <li><a href="/husky_experience_message?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
