# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-12-12 00:58
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('hx_toolkit', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='relatedarticle',
            name='parent_article',
        ),
        migrations.RemoveField(
            model_name='relatedarticle',
            name='related_article',
        ),
        migrations.DeleteModel(
            name='RelatedArticle',
        ),
    ]
