{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Fight Decision Fatigue</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/fight_decision_fatigue_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/fight_decision_fatigue_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/fight_decision_fatigue_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/fight_decision_fatigue_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/fight_decision_fatigue_650.jpg' %}"
                     alt="A tired student focused on his laptop in a study booth.">
            
            
        </figure>
        <div class="myuw-article-body">
        <h3>Strategies to Make It Easier</h3>
<p>Sometimes decisions are not life-defining, but seem soul-sucking. Study environmental science, or work on my essay for history? Go to the accounting club meeting or the leadership lecture? Decisions can be hard and take time but having  some techniques to use makes it easier.</p>
<ul>
<li>Define your choices and seek information</li>
<li>Make a pro/con list or a cost-benefit analysis</li>
<li>Imagine the advice you would give to a friend</li>
<li>Experiment with having the choice made for you and then see how you feel about it</li>
<li>Need to make a decision quickly? Set a timer!</li>
</ul>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://www.huffingtonpost.com/entry/3-powerful-decision-making-strategies-of-successful_us_57ed81e6e4b0972364deaed3">3 Powerful Decision-Making Strategies of Successful Leaders</a></li>
                
                    <li><a href="http://www.wisebread.com/10-ways-to-improve-your-decision-making-skills">10 Ways to Improve Your Decision-Making Skills</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=solve-world-problems">Solve World Problems</a></li>
                
                    <li><a href="/husky_experience_message?article=got-experience">Got Experience?</a></li>
                
                    <li><a href="/husky_experience_message?article=what-if-grade-didnt-matter">What If the Grade Didn&#39;t Matter?</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
