{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">What If the Grade Didn&#39;t Matter?</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/what_if_the_grade_didnt_matter_650.jpg' %}"
                     alt="A UW student listens attentively in a large lecture.">
            
            
        </figure>
        <div class="myuw-article-body">
        <p>UW is a “city of learning” with professors whose expertise spans a vast range of topics. Recent graduates often tell us they wish they’d taken more courses that sparked their interest, rather than sticking to courses that they “had” to take. Learn from these UW alumni and set aside an hour or two to consider courses that ignite your curiosity.</p> 


<h3>Match Interests with Courses</h3>
<p>Often, students make decisions about what courses to take based on how they believe a course will benefit them. Selecting a course based on interest is more intuitive – a felt sense of what grabs you.</p>

<p>Here are some ways to tune into your interests:</p>
<ul>
<li>What news or current events are you drawn to? What big questions keep you up at night? Identify the disciplines that will help you explore these ideas. (Tip: advisers can help!)</li>

<li>Think of a faculty member who inspires you, and look at the range of courses he or she teaches. Is there a topic you would regret not learning about?</li> 

<li><a href="http://www.washington.edu/students/timeschd/  target="_blank">Browse the time schedule</a> or <a href=" https://myplan.uw.edu/" target="_blank">search MyPlan</a> for classes that look intriguing. Does the course description draw you in?</li> 
</ul>

<p>It’s worth your time to take classes you find compelling; they can offer new ideas and open up possibilities you’d never considered before.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="http://campusgrotto.com/taking-classes-outside-your-major.html">Taking Classes Outside your Major</a></li>
                
                    <li><a href="https://www.teenvogue.com/story/classes-to-take-in-college">Why You Should Step Outside Your Major When Signing Up for Classes</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus – Learning or Competing?</a></li>
                
                    <li><a href="/husky_experience_message?article=falling-love-class">Falling in Love with a Class</a></li>
                
                    <li><a href="/husky_experience_message?article=solve-world-problems">Solve World Problems</a></li>
                
                    <li><a href="/husky_experience_message?article=are-you-your-gpa">Are you your GPA?</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
