<ul class="list-unstyled">
    
    <li><a href="/husky_experience_message?article=everything-matters-think-about-it">Everything Matters – Think About It</a></li>
    
    <li><a href="/husky_experience_message?article=plan-your-life-accident">Plan Your Life by Accident</a></li>
    
    <li><a href="/husky_experience_message?article=tools-help-you-along-way">Tools to Help You Along the Way</a></li>
    
</ul>