{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">Are you your GPA?</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/are_you_your_gpa_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/are_you_your_gpa_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/are_you_your_gpa_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/are_you_your_gpa_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/are_you_your_gpa_650.jpg' %}"
                     alt="Students in the College of Education take a quiz during class.">
            
            
        </figure>
        <div class="myuw-article-body">
        <h3>When GPAs Matter</h3>
        <p>Sometimes a high GPA matters a lot, especially if you are aspiring to graduate or professional school. If that's the case, there are many resources on campus to help you improve your skills in reading, writing, problem solving, and time management – <a href="http://webster.uaa.washington.edu/asp/website/get-help/helpful-tips/overview/">Academic Support Programs</a> is a good place to start.</p>


<h3>What Can Matter More</h3>
<p>That said, most <a href="http://www.naceweb.org/career-development/trends-and-predictions/job-outlook-2016-attributes-employers-want-to-see-on-new-college-graduates-resumes/">employers care more about your skills</a> and less about your GPA. In what ways are you cultivating your skills in leadership, communication, and teamwork? Here's where you want to think strategically about how you combine academic work and experience outside the classroom. </p>

<p>Getting experience – and even getting good grades – doesn't mean anything unless you can show that you learned. Being able to talk about what you have learned, both inside and outside the classroom, is a key skill. In the end, the whole package – your ability to apply your academic knowledge to real-world problems, your engagement in experience outside the classroom, and a strong professional network – matters more in getting a job than magna cum laude.</p>
        </div>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=your-friends-your-success">Your Friends, Your Success</a></li>
                
                    <li><a href="/husky_experience_message?article=you-are-your-network">You Are Your Network</a></li>
                
                    <li><a href="/husky_experience_message?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus – Learning or Competing?</a></li>
                
                    <li><a href="/husky_experience_message?article=got-experience">Got Experience?</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
