{% load static %}

<div class="myuw-article row">
    <div class="col-md-8">
        <h2 class="myuw-heading-page">No Time to be Healthy?</h2>
        <figure class="myuw-article-heroimage">
            
                <img class="myuw-card-image-full"
                     srcset="{% static 'hx_toolkit_output/images/no_time_to_be_healthy_480.jpg' %} 480w,
                         {% static 'hx_toolkit_output/images/no_time_to_be_healthy_650.jpg' %} 650w,
                         {% static 'hx_toolkit_output/images/no_time_to_be_healthy_780.jpg' %} 780w,
                         {% static 'hx_toolkit_output/images/no_time_to_be_healthy_1000.jpg' %} 1000w"
                     sizes="(max-width: 767px) 100vw,
                        650px"
                     src="{% static 'hx_toolkit_output/images/no_time_to_be_healthy_650.jpg' %}"
                     alt="UW Students make time to enjoy the UW/UCLA football game in 2010.">
            
            
                <p class="myuw-image-credit">Photo: Tricia Caparas</p>
            
        </figure>
        <div class="myuw-article-body">
        <p>The college lifestyle doesn’t exactly encourage discipline when it comes to getting a good night’s sleep, exercising, and eating healthy. And if you’re crazy busy or feeling stressed, the last thing you want to hear is someone reminding you to take care of your health. But you probably know this already: when you prioritize your health, tasks that seem overwhelming suddenly become manageable. And over time, you’re likely to be happier and better able to handle your work and other challenges if you attend to your wellness.</p>


<h3>Start Small and Nourish</h3>
<p>If your time is truly limited, try to make space for small activities that will restore and nourish your body and brain.</p>

<p>Here are some options we found that are great rejuvenators:</p>
<ul>
<li><strong>Breathe deeply</strong> – First thing in the morning, in the shower, on the bus, any time you think of it. Take 5-10 deep breaths that fill your belly and lungs, and exhale slowly. That extra boost of oxygen will clear your mind and help reduce stress.</li>
<li><strong>Meditate</strong> – This is more intentional deep breathing, where you find a place to sit, close your eyes, and focus carefully on your inhale and exhale. Acknowledge when thoughts appear, then go back to the breath without any judgment. 15-20 minutes is ideal.</li>
<li><strong>Engage your senses</strong> – Prepare a good meal if you can, or at least eat one, slowing down to savor the tastes and textures. Close your eyes and listen fully to your favorite music. Take a walk outside in nature, taking in the smells and temperature of the air. Draw or color. If you're so lucky, play or snuggle with a furry pet.</li>
<li><strong>Move</strong> – Do anything to get your blood pumping for at least a minute, multiple times a day. 25 jumping jacks. Wild dancing to your favorite tunes. Skipping across the quad – getting outside provides an extra boost. This kind of movement can interrupt the stress response. And it will probably make you want to move more often, for longer.</li>
<li><strong>Feel gratitude</strong> – When you spend time thinking about someone or something you appreciate, you release positive brain chemicals. New brain science says that you’re a tiny bit healthier whenever you conjure a positive emotional thought. Make it a goal every day to conjure more positive thoughts than negative. </li>
<li><strong>Say no</strong> – To whatever you know will cause you to overextend yourself. Or whatever doesn’t feel right for you.</li>
<li><strong>Say yes</strong> – To goofing around and laughing hard. To spending time talking with others – in person or on the phone. Really restorative activity gets you away from the screen.</li>
<li><strong>Sleep</strong> – Yeah, we know you’ve heard this one before, but here it is again because it’s so important. Your body needs sleep to function at its best, physically, mentally, emotionally. Can’t get 8 hours of sleep? Nap. Research says 25 minutes is good, 60-90 minutes is better.</li>
</ul>

<p>Take care of your health, and other things will look a lot more manageable.</p>
        </div>
        
            <h3 class="myuw-heading-page">Resources</h3>
            <ul>
                
                    <li><a href="https://fyp.washington.edu/healthyhuskies/">Healthy Huskies</a></li>
                
            </ul>
        

        
            <h3 class="myuw-heading-page">Related Articles</h3>
            <ul>
                
                    <li><a href="/husky_experience_message?article=wheres-your-focuslearning-or-competing">Where&#39;s Your Focus – Learning or Competing?</a></li>
                
                    <li><a href="/husky_experience_message?article=tired-feeling-alone">Tired of Feeling Alone?</a></li>
                
                    <li><a href="/husky_experience_message?article=bouncing-back">Bouncing Back</a></li>
                
            </ul>
        

        <div class="myuw-article-footer">
            <h3 class="myuw-article-footer-title">About the Husky Experience Toolkit</h3>
            <p>The <a href="/husky_experience">Husky Experience Toolkit</a> is designed to help you make the most of your time at UW, wherever you are in your university career. The articles address four interconnected dimensions of the Husky Experience: Know Yourself, Know the World, Make Your Way, and Weave it Together.
            </p>
        </div>
    </div>
</div>
